@@ -1,16 +1,13 @@
 ### import, check normalize and transform RNAseq data
 
-RNAseqdata <- function(file, backgrounddose, check = TRUE, 
-                       transfo.method, 
-                       transfo.blind = TRUE, round.counts = FALSE)
-{
-  if (is.data.frame(file))
-  {
+RNAseqdata <- function(file, backgrounddose, check = TRUE,
+                       transfo.method,
+                       transfo.blind = TRUE, round.counts = FALSE) {
+  
+  if (is.data.frame(file)) {
     d <- file
-  } else
-  {
-    if (check)
-    {
+  } else {
+    if (check) {
       # check argument file
       if (!is.character(file))
         stop("The argument file must be a character string.")
@@ -20,32 +17,29 @@ RNAseqdata <- function(file, backgrounddose, check = TRUE,
         stop("The argument file must be a character string ending by .txt.")
     }
     d <- utils::read.table(file, header = FALSE)
-    colnames(d) <- c("item",paste("S", 1:(ncol(d)-1), sep = ""))
-    
+    colnames(d) <- c("item", paste0("S", 1:(ncol(d) - 1)))
   }
+  
   nrowd <- nrow(d)
   ncold <- ncol(d)
-  data <- as.matrix(d[2:nrowd, 2:ncold]) 
+  data <- as.matrix(d[2:nrowd, 2:ncold])
   nrowdata <- nrowd - 1
   ncoldata <- ncold - 1
   
-  if(any(!stats::complete.cases(data)))
+  if (!all(stats::complete.cases(data)))
     stop("RNAseqdata() should not be used with data including NA values.")
   
-  if (round.counts)
-  {
+  if (round.counts) {
     data <- round(data)
-  } else
-  {
+  } else {
     subdata4check <- as.numeric(data[1:min(nrowdata, 10), ])
     subdata4checkT <- trunc(subdata4check)
     if (!identical(subdata4check, subdata4checkT))
       stop("Your data contain non integer values. Make sure that your RNAseq data are imported in raw counts.
-      If your counts come from Kallisto or Salmon put the argument round.counts of RNAseqdata at TRUE to round them.\n") 
+      If your counts come from Kallisto or Salmon put the argument round.counts of RNAseqdata at TRUE to round them.\n")
   }
   
-  if (check)
-  {
+  if (check) {
     if (nrowdata < 100)
       warning(strwrap(prefix = "\n", initial = "\n",
                       "Your dataset contains less than 100 lines. Are you sure you really
@@ -53,27 +47,30 @@ RNAseqdata <- function(file, backgrounddose, check = TRUE,
       not be used with another type of data."))
     
     # check that doses and responses are numeric
-    if (!is.numeric(as.matrix(d[,2:ncold])))
+    if (!is.numeric(as.matrix(d[, 2:ncold])))
       stop("All the columns except the first one must be numeric with the numeric dose in the firt line 
       and the read counts (integer values corresponding to raw counts) of each item in the other lines.")
   }
   
   # Normalization and count data transformation using DESeq2
-  if (missing(transfo.method))
-  {
-    if (ncoldata > 30) {transfo.method <- "vst"} else {transfo.method <- "rlog"}
-  } else
-  {
+  if (missing(transfo.method)) {
+    if (ncoldata > 30) {
+      transfo.method <- "vst"
+    } else {
+      transfo.method <- "rlog"
+    }
+  } else {
     transfo.method <- match.arg(transfo.method, c("rlog", "vst"))
   }
-  if(transfo.method == "rlog")
+  if (transfo.method == "rlog")
     cat(strwrap(paste0("Just wait, the transformation using regularized logarithm (rlog) may take a few minutes.\n")), fill = TRUE)
   
   raw.counts <- data
   (dose <- as.vector(unlist(d[1, 2:ncold])))
   
-  if(!transfo.blind)
-  {
+  
+  if (!transfo.blind) {
+    fdose <- as.factor(dose)
     coldata <- data.frame(fdose = fdose)
     rownames(coldata) <- colnames(data)
     dds <- DESeqDataSetFromMatrix(
@@ -81,48 +78,34 @@ RNAseqdata <- function(file, backgrounddose, check = TRUE,
       colData = coldata,
       design = ~ fdose)
   }
-    
-  if (transfo.method == "rlog")
-  {
-    if (transfo.blind) 
-    {
+  
+  if (transfo.method == "rlog") {
+    if (transfo.blind) {
       data <- rlog(raw.counts)
-    } else
-    {
-        data <- assay(rlog(dds, blind = FALSE))  
+    } else {
+      data <- assay(rlog(dds, blind = FALSE))
     }
-  } else # transfo.method == "vst"
-  {
+  } else { # transfo.method == "vst"
     nsub <- 1000 # parameter of vst to speed computation
-    if (transfo.blind) 
-    {
-      if (nrowdata < nsub)
-      {
+    if (transfo.blind) {
+      if (nrowdata < nsub) {
         data <- varianceStabilizingTransformation(raw.counts)
-      } else
-      {
+      } else {
         tryvst <- try(vst(raw.counts, nsub = nsub), silent = TRUE)
-        if (!inherits(tryvst, "try-error"))
-        {
+        if (!inherits(tryvst, "try-error")) {
           data <- tryvst
-        } else
-        {
+        } else {
           data <- varianceStabilizingTransformation(raw.counts)
         }
       }
-    } else # VST is not blind to the experimental design
-    {
-      if (nrowdata < nsub)
-      {
+    } else { # VST is not blind to the experimental design
+      if (nrowdata < nsub) {
         data <- assay(varianceStabilizingTransformation(dds, blind = FALSE))
-      } else
-      {
+      } else {
         tryvst <- try(vst(dds, nsub = nsub, blind = FALSE), silent = TRUE)
-        if (!inherits(tryvst, "try-error"))
-        {
+        if (!inherits(tryvst, "try-error")) {
           data <- assay(tryvst)
-        } else
-        {
+        } else {
           data <- assay(varianceStabilizingTransformation(dds, blind = FALSE))
         }
       }
@@ -133,8 +116,7 @@ RNAseqdata <- function(file, backgrounddose, check = TRUE,
   row.names(data) <- item <- as.character(d[2:nrowd, 1])
   (nitems <- nrow(data))
   
-  if (!missing(backgrounddose))
-  {
+  if (!missing(backgrounddose)) {
     dose <- dose * (dose > backgrounddose)
   }
   
@@ -150,7 +132,7 @@ RNAseqdata <- function(file, backgrounddose, check = TRUE,
   design <- table(dose, dnn = "")
   nbdoses <- length(design)
   nbpts <- sum(design)
-  if ((nbdoses < 4)| (nbpts < 8))
+  if ((nbdoses < 4) || (nbpts < 8))
     stop("Dromics cannot be used with a dose-response design 
     with less than four tested doses/concentrations or less than eight data points
          per dose-response curve.")
@@ -162,25 +144,29 @@ RNAseqdata <- function(file, backgrounddose, check = TRUE,
   # calculation of the means per dose
   fdose <- as.factor(dose)
   tdata <- t(data)
-  calcmean <- function(i)
-  {
-  #   tapply(data[i,], fdose, mean)
+  calcmean <- function(i) {
     tapply(tdata[, i], fdose, mean)
   }
   s <- sapply(1:(nrowd - 1), calcmean)
   data.mean <- as.matrix(t(s))
   
-  reslist <- list(data = data, dose = dose, item = item, 
-                  design = design, data.mean = data.mean, 
+  calcsd <- function(i) {
+    tapply(tdata[, i], fdose, sd)
+  }
+  s <- sapply(1:(nrowd - 1), calcsd)
+  data.sd <- as.matrix(t(s))
+  
+  reslist <- list(data = data, dose = dose, item = item,
+                  design = design, data.mean = data.mean,
+                  data.sd = data.sd,
                   transfo.method = transfo.method, raw.counts = raw.counts,
-                  containsNA = FALSE)  
+                  containsNA = FALSE)
   
   return(structure(reslist, class = "RNAseqdata"))
 }
 
 
-print.RNAseqdata <- function(x, ...)
-{
+print.RNAseqdata <- function(x, ...) {
   if (!inherits(x, "RNAseqdata"))
     stop("Use only with 'RNAseqdata' objects.")
   
@@ -189,12 +175,10 @@ print.RNAseqdata <- function(x, ...)
   print(x$design)
   cat("Number of items:", length(x$item), "\n")
   
-  if (length(x$item) > 20)
-  {
+  if (length(x$item) > 20) {
     cat("Identifiers of the first 20 items:\n")
     print(x$item[1:20])
-  } else
-  {
+  } else {
     cat("Identifiers of the items:\n")
     print(x$item)
   }
@@ -202,24 +186,21 @@ print.RNAseqdata <- function(x, ...)
                      and tranformed using the following method: ", x$transfo.method)), fill = TRUE)
 }
 
-plot.RNAseqdata <- function(x, range4boxplot = 1e6, ...) 
-{
+plot.RNAseqdata <- function(x, range4boxplot = 0, ...) {
   if (!inherits(x, "RNAseqdata"))
     stop("Use only with 'RNAseqdata' objects.")
   
   def.par <- graphics::par(no.readonly = TRUE)
   ymin.rc <- min(x$raw.counts)
   ymax.rc <- max(x$raw.counts)
-  graphics::par(mfrow = c(1,2), xaxt = "n")
-  graphics::boxplot(x$raw.counts, xlab = "Samples", ylab = "Raw counts", 
-          main = paste("Raw data"), 
-          ylim = c(ymin.rc, ymax.rc), range = range4boxplot, ...) 
+  graphics::par(mfrow = c(1, 2), xaxt = "n")
+  graphics::boxplot(x$raw.counts, xlab = "Samples", ylab = "Raw counts",
+                    main = "Raw data",
+                    ylim = c(ymin.rc, ymax.rc), range = range4boxplot, ...)
   ymin.log <- min(x$data)
   ymax.log <- max(x$data)
-  graphics::boxplot(x$data, xlab = "Samples", ylab = "Signal", 
-          main = paste("Normalized and transformed data"), 
-          ylim = c(ymin.log, ymax.log), range = range4boxplot, ...)   
-  graphics::par(def.par)    
+  graphics::boxplot(x$data, xlab = "Samples", ylab = "Signal",
+                    main = "Normalized and transformed data",
+                    ylim = c(ymin.log, ymax.log), range = range4boxplot, ...)
+  graphics::par(def.par)
 }
-
-
